"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MonitorActivityStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MonitorActivityStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MonitorActivityStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MONITOR_STATUS_INVALID: _MonitorActivityStatus.ValueType  # 0
    """Default invalid State"""
    MONITOR_STATUS_ACTIVE: _MonitorActivityStatus.ValueType  # 1
    """Marks the account is currently active in Qwak"""
    MONITOR_STATUS_DISABLED: _MonitorActivityStatus.ValueType  # 2
    """Marks that the account is disabled"""

class MonitorActivityStatus(_MonitorActivityStatus, metaclass=_MonitorActivityStatusEnumTypeWrapper): ...

MONITOR_STATUS_INVALID: MonitorActivityStatus.ValueType  # 0
"""Default invalid State"""
MONITOR_STATUS_ACTIVE: MonitorActivityStatus.ValueType  # 1
"""Marks the account is currently active in Qwak"""
MONITOR_STATUS_DISABLED: MonitorActivityStatus.ValueType  # 2
"""Marks that the account is disabled"""
global___MonitorActivityStatus = MonitorActivityStatus

class AlertingChannelCreateOptions(google.protobuf.message.Message):
    """Arguments for updating a new alerting channel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name for the alerting channel (unique per account)"""
    @property
    def spec(self) -> global___AlertingChannelSpec:
        """Specification for alerting channel"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        spec: global___AlertingChannelSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "spec", b"spec"]) -> None: ...

global___AlertingChannelCreateOptions = AlertingChannelCreateOptions

class AlertingChannelUpdateOptions(google.protobuf.message.Message):
    """Arguments for updating a new alerting channel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Id of the alerting channel to update"""
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue:
        """New name for the channel (optional)"""
    @property
    def spec(self) -> global___AlertingChannelSpec:
        """New specification for the channel (optional)"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: google.protobuf.wrappers_pb2.StringValue | None = ...,
        spec: global___AlertingChannelSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["name", b"name", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "spec", b"spec"]) -> None: ...

global___AlertingChannelUpdateOptions = AlertingChannelUpdateOptions

class AlertingChannelDescription(google.protobuf.message.Message):
    """a full description of alerting channel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___AlertingChannelMetadata:
        """Meta data of the alerting channel"""
    @property
    def spec(self) -> global___AlertingChannelSpec:
        """Specification of the alerting channel"""
    def __init__(
        self,
        *,
        metadata: global___AlertingChannelMetadata | None = ...,
        spec: global___AlertingChannelSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec", b"spec"]) -> None: ...

global___AlertingChannelDescription = AlertingChannelDescription

class AlertingChannelMetadata(google.protobuf.message.Message):
    """Meta data of the alerting channel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    DELETED_AT_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """Account id that owned the alerting channel"""
    id: builtins.str
    """Id of the alerting channel"""
    name: builtins.str
    """Name of the alerting channel"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation time of alerting channel"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last modification time of alerting channel"""
    @property
    def deleted_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last deleted time of alerting channel"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        deleted_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "deleted_at", b"deleted_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "created_at", b"created_at", "deleted_at", b"deleted_at", "id", b"id", "last_modified_at", b"last_modified_at", "name", b"name"]) -> None: ...

global___AlertingChannelMetadata = AlertingChannelMetadata

class AlertingChannelSpec(google.protobuf.message.Message):
    """Specification of the alerting channel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def configuration(self) -> global___ChannelConfiguration:
        """Configuration of the alerting channel"""
    def __init__(
        self,
        *,
        configuration: global___ChannelConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> None: ...

global___AlertingChannelSpec = AlertingChannelSpec

class ChannelConfiguration(google.protobuf.message.Message):
    """Configuration of the alerting channel"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_FIELD_NUMBER: builtins.int
    PAGERDUTY_FIELD_NUMBER: builtins.int
    OPSGENIE_FIELD_NUMBER: builtins.int
    @property
    def slack(self) -> global___SlackType:
        """Channel from type slack"""
    @property
    def pagerduty(self) -> global___PagerDutyType:
        """Channel from type Pagerduty"""
    @property
    def opsgenie(self) -> global___OpsgenieType:
        """Channel from type Opsgenie"""
    def __init__(
        self,
        *,
        slack: global___SlackType | None = ...,
        pagerduty: global___PagerDutyType | None = ...,
        opsgenie: global___OpsgenieType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["channel_type", b"channel_type", "opsgenie", b"opsgenie", "pagerduty", b"pagerduty", "slack", b"slack"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_type", b"channel_type", "opsgenie", b"opsgenie", "pagerduty", b"pagerduty", "slack", b"slack"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["channel_type", b"channel_type"]) -> typing_extensions.Literal["slack", "pagerduty", "opsgenie"] | None: ...

global___ChannelConfiguration = ChannelConfiguration

class SyncResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNELS_TO_SYNC_FIELD_NUMBER: builtins.int
    ALREADY_UP_TO_DATE_FIELD_NUMBER: builtins.int
    @property
    def channels_to_sync(self) -> global___AlertingChannelToSync:
        """A response in case there are channels to sync"""
    @property
    def already_up_to_date(self) -> global___AlertingChannelsAlreadyUpToDate:
        """An indicator to a state which all channels are already synchronized"""
    def __init__(
        self,
        *,
        channels_to_sync: global___AlertingChannelToSync | None = ...,
        already_up_to_date: global___AlertingChannelsAlreadyUpToDate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["already_up_to_date", b"already_up_to_date", "channels_to_sync", b"channels_to_sync", "types", b"types"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["already_up_to_date", b"already_up_to_date", "channels_to_sync", b"channels_to_sync", "types", b"types"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["types", b"types"]) -> typing_extensions.Literal["channels_to_sync", "already_up_to_date"] | None: ...

global___SyncResponse = SyncResponse

class AlertingChannelToSync(google.protobuf.message.Message):
    """List of alerting channels to sync to clusters"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    CHANNELS_TO_DELETE_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlertingChannelDescription]: ...
    @property
    def channels_to_delete(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlertingChannelDescription]:
        """A response in case there are channels to delete"""
    def __init__(
        self,
        *,
        description: collections.abc.Iterable[global___AlertingChannelDescription] | None = ...,
        channels_to_delete: collections.abc.Iterable[global___AlertingChannelDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channels_to_delete", b"channels_to_delete", "description", b"description"]) -> None: ...

global___AlertingChannelToSync = AlertingChannelToSync

class AlertingChannelToDelete(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlertingChannelDescription]: ...
    def __init__(
        self,
        *,
        description: collections.abc.Iterable[global___AlertingChannelDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description"]) -> None: ...

global___AlertingChannelToDelete = AlertingChannelToDelete

class AlertingChannelsAlreadyUpToDate(google.protobuf.message.Message):
    """No new Channels to sync into clusters"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AlertingChannelsAlreadyUpToDate = AlertingChannelsAlreadyUpToDate

class SlackType(google.protobuf.message.Message):
    """Channel from type slack"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_URL_FIELD_NUMBER: builtins.int
    @property
    def api_url(self) -> global___SecretStringValue:
        """Api url for slack channel"""
    def __init__(
        self,
        *,
        api_url: global___SecretStringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api_url", b"api_url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_url", b"api_url"]) -> None: ...

global___SlackType = SlackType

class PagerDutyType(google.protobuf.message.Message):
    """Channel from type Pagerduty"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_KEY_FIELD_NUMBER: builtins.int
    SERVICE_KEY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def routing_key(self) -> global___SecretStringValue:
        """Routing key for pd"""
    @property
    def service_key(self) -> global___SecretStringValue:
        """Service key for pd"""
    url: builtins.str
    """Url for pd"""
    def __init__(
        self,
        *,
        routing_key: global___SecretStringValue | None = ...,
        service_key: global___SecretStringValue | None = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["routing_key", b"routing_key", "service_key", b"service_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["routing_key", b"routing_key", "service_key", b"service_key", "url", b"url"]) -> None: ...

global___PagerDutyType = PagerDutyType

class OpsgenieType(google.protobuf.message.Message):
    """Channel from type Opsgenie"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    @property
    def api_key(self) -> global___SecretStringValue:
        """Api key for opsgenie"""
    def __init__(
        self,
        *,
        api_key: global___SecretStringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api_key", b"api_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key"]) -> None: ...

global___OpsgenieType = OpsgenieType

class SecretStringValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___SecretStringValue = SecretStringValue



import random
from typing import Dict, List, Optional, Union

from qwak.clients.integration_management.integration_utils import IntegrationUtils
from qwak.clients.integration_management.openai.openai_system_secret import (
    OpenAIApiKeySystemSecret,
)
from qwak.exceptions import QwakException
from qwak.llmops.generation.chat.openai.types.chat.chat_completion import ChatCompletion
from qwak.llmops.generation.streaming import ChatCompletionStream
from qwak.llmops.model.descriptor import OpenAIChat
from qwak.llmops.prompt.chat.message import (
    AIMessage,
    BaseMessage,
    HumanMessage,
    SystemMessage,
)
from qwak.llmops.prompt.chat.value import ChatPromptValue
from qwak.llmops.provider.openai.client import OpenAIClient


class OpenAIProvider:
    client: OpenAIClient

    def __init__(self):
        self.client = OpenAIClient()

    def _get_random_openai_api_key(self) -> Optional[str]:
        openai_api_keys: List[
            OpenAIApiKeySystemSecret
        ] = IntegrationUtils().get_openai_api_keys()
        if len(openai_api_keys) == 0:
            return None

        return random.choice(openai_api_keys).get_api_key()  # nosec

    def _chat_value_to_json(self, chat_prompt_value: ChatPromptValue) -> List[Dict]:
        return [self._map_message(m) for m in chat_prompt_value.messages]

    def _map_message(self, message: BaseMessage) -> Dict[str, str]:
        role: str
        content: str = message.content

        if isinstance(message, AIMessage):
            role = "assistant"
        elif isinstance(message, SystemMessage):
            role = "system"
        elif isinstance(message, HumanMessage):
            role = "user"
        else:
            raise QwakException(f"Can't handle message of type: {repr(message)}")

        return {"role": role, "content": content}

    def create_chat_completion(
        self,
        chat_prompt_value: ChatPromptValue,
        chat_model_descriptor: OpenAIChat,
        stream: bool = False,
    ) -> Union[ChatCompletion, ChatCompletionStream]:
        openai_api_key: Optional[str] = self._get_random_openai_api_key()
        if not openai_api_key:
            raise QwakException(
                "Could not find Open AI integration, Please create one."
            )

        d = chat_model_descriptor

        return self.client.invoke_chat_completion(
            stream=stream,
            api_key=openai_api_key,
            model=d.model_id,
            messages=self._chat_value_to_json(chat_prompt_value),
            frequency_penalty=d.frequency_penalty,
            logit_bias=d.logit_bias,
            logprobs=d.logprobs,
            max_tokens=d.max_tokens,
            n=d.n,
            presence_penalty=d.presence_penalty,
            response_format=d.response_format,
            seed=d.seed,
            stop=d.stop,
            temperature=d.temperature,
            top_logprobs=d.top_logprobs,
            top_p=d.top_p,
            user=d.user,
            tool_choice=d.tool_choice,
            tools=d.tools,
        )



from abc import ABC, abstractmethod
from dataclasses import dataclass, field
from enum import Enum
from typing import Callable, Optional, Type

from _qwak_proto.qwak.feature_store.sources.streaming_pb2 import (
    CustomDeserializer as ProtoCustomDeserializer,
    Deserialization as ProtoDeserialization,
    GenericDeserializer as ProtoGenericDeserializer,
    MessageFormat as ProtoMessageFormat,
)
from qwak.exceptions import QwakException


class MessageFormat(Enum):
    JSON = ProtoMessageFormat.JSON
    AVRO = ProtoMessageFormat.AVRO


class Deserializer(ABC):
    @abstractmethod
    def _to_proto(self, artifact_path: Optional[str] = None) -> ProtoDeserialization:
        pass

    @abstractmethod
    def _get_function(self) -> Optional[Callable]:
        pass

    @classmethod
    def _from_proto(
        cls,
        proto_deserializer: ProtoDeserialization,
    ) -> Type["Deserializer"]:
        deserializer = getattr(
            proto_deserializer, proto_deserializer.WhichOneof("type")
        )

        if isinstance(deserializer, ProtoGenericDeserializer):
            return GenericDeserializer._from_proto(proto_deserializer=deserializer)
        elif isinstance(deserializer, ProtoCustomDeserializer):
            return CustomDeserializer._from_proto(proto_deserializer=deserializer)
        else:
            raise QwakException(f"Got unsupported deserializer type {deserializer}")


@dataclass
class GenericDeserializer(Deserializer):
    message_format: MessageFormat
    schema: str

    def _to_proto(self, artifact_path: Optional[str] = None) -> ProtoDeserialization:
        # TODO: add backend schema validation
        return ProtoDeserialization(
            generic_deserializer=ProtoGenericDeserializer(
                deserializer_format=self.message_format.value, schema=self.schema
            )
        )

    def _get_function(self) -> Optional[Callable]:
        return None

    @classmethod
    def _from_proto(
        cls, proto_deserializer: ProtoGenericDeserializer
    ) -> Type["GenericDeserializer"]:
        return cls(
            message_format=MessageFormat(proto_deserializer.deserializer_format),
            schema=proto_deserializer.schema,
        )


@dataclass
class CustomDeserializer(Deserializer):
    function: Callable
    _artifact_path: Optional[str] = field(init=False, default=None)

    def _to_proto(self, artifact_path: Optional[str] = None) -> ProtoDeserialization:
        self._validate()

        if artifact_path:
            self._artifact_path = artifact_path

        # TODO: add backend schema validation
        return ProtoDeserialization(
            custom_deserializer=ProtoCustomDeserializer(
                function_name=self.function.__name__, artifact_path=self._artifact_path
            )
        )

    @classmethod
    def _from_proto(
        cls, proto_deserializer: ProtoCustomDeserializer
    ) -> Type["CustomDeserializer"]:
        def dummy_deserializer(df):
            return df

        custom_function: Callable = dummy_deserializer
        custom_function.__name__ = proto_deserializer.function_name

        return cls(function=custom_function)

    def _validate(self):
        if self.function is None:
            raise QwakException("deserialization function must be set!")
        if self.function.__name__ == "<lambda>":
            raise QwakException("Custom Deserializer can not be set with a lambda")

    def _get_function(self) -> Optional[Callable]:
        return self.function



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.data_versioning import data_versioning_service_pb2 as qwak_dot_data__versioning_dot_data__versioning__service__pb2


class DataVersioningManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterDataTag = channel.unary_unary(
                '/qwak.management.data_versioning.DataVersioningManagementService/RegisterDataTag',
                request_serializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.RegisterDataTagRequest.SerializeToString,
                response_deserializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.RegisterDataTagResponse.FromString,
                )
        self.GetModelDataTags = channel.unary_unary(
                '/qwak.management.data_versioning.DataVersioningManagementService/GetModelDataTags',
                request_serializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.GetModelDataTagsRequest.SerializeToString,
                response_deserializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.GetModelDataTagsResponse.FromString,
                )


class DataVersioningManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterDataTag(self, request, context):
        """Register data tag
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelDataTags(self, request, context):
        """Get the models tags
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataVersioningManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterDataTag': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterDataTag,
                    request_deserializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.RegisterDataTagRequest.FromString,
                    response_serializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.RegisterDataTagResponse.SerializeToString,
            ),
            'GetModelDataTags': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelDataTags,
                    request_deserializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.GetModelDataTagsRequest.FromString,
                    response_serializer=qwak_dot_data__versioning_dot_data__versioning__service__pb2.GetModelDataTagsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.management.data_versioning.DataVersioningManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataVersioningManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterDataTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.management.data_versioning.DataVersioningManagementService/RegisterDataTag',
            qwak_dot_data__versioning_dot_data__versioning__service__pb2.RegisterDataTagRequest.SerializeToString,
            qwak_dot_data__versioning_dot_data__versioning__service__pb2.RegisterDataTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelDataTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.management.data_versioning.DataVersioningManagementService/GetModelDataTags',
            qwak_dot_data__versioning_dot_data__versioning__service__pb2.GetModelDataTagsRequest.SerializeToString,
            qwak_dot_data__versioning_dot_data__versioning__service__pb2.GetModelDataTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import dataclasses
from typing import List, cast

from qwak.clients.administration.eco_system.eco_system_utils import EcosystemUtils
from qwak.exceptions import QwakException
from qwak.model.schema_entities import BaseFeature, FeatureStoreInput


def validate_and_sanitize_feature_name(feature_name: str, current_env_name: str) -> str:
    qualifiers = feature_name.split(".")
    if len(qualifiers) <= 1:
        raise QwakException(
            f"Feature name '{feature_name}' must adhere to the <featureset_name>.<feature_name> or <env_name>.<featureset_name>.<feature_name> convention"
        )
    elif len(qualifiers) == 2:  # env name is not included in the feature name
        feature_name = f"{current_env_name}.{feature_name}"
    return feature_name.lower()


def validate_and_sanitize_features_name(
    features: List[BaseFeature],
) -> List[BaseFeature]:
    """
    Verify that the features (from type FeatureStoreInput) names are valid and adhere to convention <featureset_name>.<feature_name> or <env_name>.<featureset_name>.<feature_name>
    Add the current env qualifier if env is missing and transform name to lowercase
    :param features:
    :return: sanitized features with lower case (to support case-insensitive) fully qualified feature names
    :exception QwakException: if the feature name does not adhere to the convention
    """
    ecosystem_utils = EcosystemUtils()
    current_env_name = ecosystem_utils.get_current_environment_name()
    return [
        cast(
            FeatureStoreInput,
            dataclasses.replace(
                feature,
                name=validate_and_sanitize_feature_name(feature.name, current_env_name),
            ),
        )
        if isinstance(feature, FeatureStoreInput)
        else feature
        for feature in features
    ]


def extract_env_name(feature_name: str) -> str:
    """
    extracts env_name from featureset name
    assuming feature name is fully qualified (passed sanitization)
    :param feature_name:
    :return: env_name
    """
    qualifiers = feature_name.split(".")
    return ".".join(qualifiers[:-2])  # Everything except the last two parts


def extract_featureset_name(feature_name: str) -> str:
    qualifiers = feature_name.split(".")
    return qualifiers[-2]


def discard_env_from_name(
    feature_name: str,
) -> str:
    return ".".join(feature_name.split(".")[-2:])



import shutil
import re
from pathlib import Path
from typing import List, Optional

from qwak.exceptions import QwakSuggestionException
from qwak.inner.build_logic.tools.files import (
    copytree,
    get_possible_dependency_lock_paths,
)

from ...common import get_git_commit_id
from ..strategy import Strategy, get_ignore_pattern


class FolderStrategy(Strategy):
    def fetch(
        self,
        src: str,
        dest: str,
        custom_dependencies_path: Optional[str],
        main_dir: str,
        dependency_path: str,
        lock_dependency_path: str,
        dependency_required_folders: List[str],
        **kwargs,
    ) -> Optional[str]:
        try:
            self.build_logger.debug(
                f"Fetching Model code from local directory -  {src}"
            )

            ignore_patterns, patterns_for_printing = get_ignore_pattern(
                src, main_dir, self.build_logger
            )
            self.build_logger.debug(
                f"Will ignore the following files: {patterns_for_printing}."
            )

            copytree(
                src=Path(src) / main_dir,
                dst=Path(dest) / main_dir,
                ignore=ignore_patterns,
            )

            self._copy_dependency_required_folders(
                dependency_required_folders, src, dest, ignore_patterns
            )

            if (Path(src) / "tests").exists():
                copytree(
                    src=Path(src) / "tests",
                    dst=Path(dest) / "tests",
                    ignore=ignore_patterns,
                )
            if dependency_path:
                shutil.copy(
                    src=Path(src) / dependency_path, dst=Path(dest) / dependency_path
                )
            if lock_dependency_path:
                if (Path(src) / lock_dependency_path).is_file():
                    shutil.copy(
                        src=Path(src) / lock_dependency_path,
                        dst=Path(dest) / lock_dependency_path,
                    )
                else:
                    self.build_logger.warning(
                        "No lock dependency file found in model directory."
                    )

            self._copy_custom_dependencies(custom_dependencies_path, dest)
            # Get git commit id if exists
            return get_git_commit_id(src, self.build_logger)
        except Exception as e:
            if isinstance(e, QwakSuggestionException):
                raise e  # Propagate suggestions without changes
            main_dir_path = Path(src) / main_dir
            if not main_dir_path.exists():
                message = f"""Seems like you're running the 'qwak models build' command from the wrong location.
Please make sure you run the command at the parent directory of your '{main_dir}' folder"""
            else:
                message = (f"Please make sure that {src} has read permissions.",)

            raise QwakSuggestionException(
                message="Unable to copy model",
                src_exception=e,
                suggestion=message,
            )

    def _copy_dependency_required_folders(
        self, dependency_required_folders, src, dest, ignore_patterns
    ):
        for folder in dependency_required_folders:
            destination_folder = folder
            while destination_folder.startswith(".."):
                destination_folder = re.sub(r"^\.\./", "", destination_folder)

            if (Path(dest) / destination_folder).exists():
                raise QwakSuggestionException(
                    message="Unable to copy model",
                    suggestion=f"It's not possible to copy directory `{folder}` into `{destination_folder}` because the target `{destination_folder}` already exist. Mixing files from multiple sources is not allowed.",
                )
            if (Path(src) / folder).exists():
                copytree(
                    src=Path(src) / folder,
                    dst=Path(dest) / destination_folder,
                    ignore=ignore_patterns,
                )
            else:
                self.build_logger.warning(
                    'Folder "{}" does not exist. Skipping it.'.format(folder)
                )

    def _copy_custom_dependencies(self, custom_dependencies_path, dest):
        if custom_dependencies_path and Path(custom_dependencies_path).is_file():
            shutil.copy(
                src=custom_dependencies_path,
                dst=Path(dest) / Path(custom_dependencies_path).name,
            )
            possible_dependency_lock_paths = get_possible_dependency_lock_paths(
                Path(custom_dependencies_path)
            )
            for path in possible_dependency_lock_paths:
                if path.is_file():
                    self.build_logger.info(
                        "Found dependency lock file: {}".format(path)
                    )
                    shutil.copy(
                        src=path,
                        dst=Path(dest) / path.name,
                    )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import google.protobuf.descriptor
import google.protobuf.message

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PrometheusConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PrometheusConfiguration = PrometheusConfiguration



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/user_application_instance/v0/user_application_instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.user_application_instance.v0 import user_application_instance_pb2 as qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQqwak/admiral/user_application_instance/v0/user_application_instance_service.proto\x12!qwak.admiral.user_app_instance.v0\x1aIqwak/admiral/user_application_instance/v0/user_application_instance.proto\"p\n$CreateUserApplicationInstanceRequest\x12H\n\x0e\x63reate_options\x18\x01 \x01(\x0b\x32\x30.qwak.admiral.user_app_instance.v0.CreateOptions\"\'\n%CreateUserApplicationInstanceResponse\"x\n(UpdateUserApplicationInstanceSpecRequest\x12L\n\x0eupdate_options\x18\x01 \x01(\x0b\x32\x34.qwak.admiral.user_app_instance.v0.UpdateSpecOptions\"+\n)UpdateUserApplicationInstanceSpecResponse\"f\n!GetUserApplicationInstanceRequest\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\"i\n\"GetUserApplicationInstanceResponse\x12\x43\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32..qwak.admiral.user_app_instance.v0.Description\"i\n$DeleteUserApplicationInstanceRequest\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\"\'\n%DeleteUserApplicationInstanceResponse2\xf7\x05\n\x1eUserApplicationInstanceService\x12\xb2\x01\n\x1d\x43reateUserApplicationInstance\x12G.qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceRequest\x1aH.qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceResponse\x12\xbe\x01\n!UpdateUserApplicationInstanceSpec\x12K.qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecRequest\x1aL.qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecResponse\x12\xa9\x01\n\x1aGetUserApplicationInstance\x12\x44.qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceRequest\x1a\x45.qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceResponse\x12\xb2\x01\n\x1d\x44\x65leteUserApplicationInstance\x12G.qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceRequest\x1aH.qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceResponseB\xbe\x01\n(com.qwak.ai.admiral.user_app_instance.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0b\x06proto3')



_CREATEUSERAPPLICATIONINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['CreateUserApplicationInstanceRequest']
_CREATEUSERAPPLICATIONINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['CreateUserApplicationInstanceResponse']
_UPDATEUSERAPPLICATIONINSTANCESPECREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserApplicationInstanceSpecRequest']
_UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE = DESCRIPTOR.message_types_by_name['UpdateUserApplicationInstanceSpecResponse']
_GETUSERAPPLICATIONINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['GetUserApplicationInstanceRequest']
_GETUSERAPPLICATIONINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['GetUserApplicationInstanceResponse']
_DELETEUSERAPPLICATIONINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteUserApplicationInstanceRequest']
_DELETEUSERAPPLICATIONINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['DeleteUserApplicationInstanceResponse']
CreateUserApplicationInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateUserApplicationInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERAPPLICATIONINSTANCEREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceRequest)
  })
_sym_db.RegisterMessage(CreateUserApplicationInstanceRequest)

CreateUserApplicationInstanceResponse = _reflection.GeneratedProtocolMessageType('CreateUserApplicationInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERAPPLICATIONINSTANCERESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceResponse)
  })
_sym_db.RegisterMessage(CreateUserApplicationInstanceResponse)

UpdateUserApplicationInstanceSpecRequest = _reflection.GeneratedProtocolMessageType('UpdateUserApplicationInstanceSpecRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERAPPLICATIONINSTANCESPECREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecRequest)
  })
_sym_db.RegisterMessage(UpdateUserApplicationInstanceSpecRequest)

UpdateUserApplicationInstanceSpecResponse = _reflection.GeneratedProtocolMessageType('UpdateUserApplicationInstanceSpecResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecResponse)
  })
_sym_db.RegisterMessage(UpdateUserApplicationInstanceSpecResponse)

GetUserApplicationInstanceRequest = _reflection.GeneratedProtocolMessageType('GetUserApplicationInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERAPPLICATIONINSTANCEREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceRequest)
  })
_sym_db.RegisterMessage(GetUserApplicationInstanceRequest)

GetUserApplicationInstanceResponse = _reflection.GeneratedProtocolMessageType('GetUserApplicationInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERAPPLICATIONINSTANCERESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceResponse)
  })
_sym_db.RegisterMessage(GetUserApplicationInstanceResponse)

DeleteUserApplicationInstanceRequest = _reflection.GeneratedProtocolMessageType('DeleteUserApplicationInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERAPPLICATIONINSTANCEREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceRequest)
  })
_sym_db.RegisterMessage(DeleteUserApplicationInstanceRequest)

DeleteUserApplicationInstanceResponse = _reflection.GeneratedProtocolMessageType('DeleteUserApplicationInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERAPPLICATIONINSTANCERESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceResponse)
  })
_sym_db.RegisterMessage(DeleteUserApplicationInstanceResponse)

_USERAPPLICATIONINSTANCESERVICE = DESCRIPTOR.services_by_name['UserApplicationInstanceService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.admiral.user_app_instance.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0'
  _CREATEUSERAPPLICATIONINSTANCEREQUEST._serialized_start=195
  _CREATEUSERAPPLICATIONINSTANCEREQUEST._serialized_end=307
  _CREATEUSERAPPLICATIONINSTANCERESPONSE._serialized_start=309
  _CREATEUSERAPPLICATIONINSTANCERESPONSE._serialized_end=348
  _UPDATEUSERAPPLICATIONINSTANCESPECREQUEST._serialized_start=350
  _UPDATEUSERAPPLICATIONINSTANCESPECREQUEST._serialized_end=470
  _UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE._serialized_start=472
  _UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE._serialized_end=515
  _GETUSERAPPLICATIONINSTANCEREQUEST._serialized_start=517
  _GETUSERAPPLICATIONINSTANCEREQUEST._serialized_end=619
  _GETUSERAPPLICATIONINSTANCERESPONSE._serialized_start=621
  _GETUSERAPPLICATIONINSTANCERESPONSE._serialized_end=726
  _DELETEUSERAPPLICATIONINSTANCEREQUEST._serialized_start=728
  _DELETEUSERAPPLICATIONINSTANCEREQUEST._serialized_end=833
  _DELETEUSERAPPLICATIONINSTANCERESPONSE._serialized_start=835
  _DELETEUSERAPPLICATIONINSTANCERESPONSE._serialized_end=874
  _USERAPPLICATIONINSTANCESERVICE._serialized_start=877
  _USERAPPLICATIONINSTANCESERVICE._serialized_end=1636
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/v0/ecosystem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2
from _qwak_proto.qwak.administration.account.v1 import terms_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_terms__pb2
from _qwak_proto.qwak.administration.account.v1 import account_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__pb2
from _qwak_proto.qwak.administration.account.v1 import jfrog_tenant_details_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_jfrog__tenant__details__pb2
from _qwak_proto.qwak.administration.v0.environments import configuration_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_configuration__pb2
from _qwak_proto.qwak.administration.v0.users import user_pb2 as qwak_dot_administration_dot_v0_dot_users_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/ecosystem/v0/ecosystem.proto\x12\x11qwak.ecosystem.v0\x1a\x30qwak/administration/account/v1/preferences.proto\x1a*qwak/administration/account/v1/terms.proto\x1a,qwak/administration/account/v1/account.proto\x1a\x39qwak/administration/account/v1/jfrog_tenant_details.proto\x1a\x37qwak/administration/v0/environments/configuration.proto\x1a\'qwak/administration/v0/users/user.proto\"<\n\x16UsernamePasswordMethod\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"(\n\x10QwakApiKeyMethod\x12\x14\n\x0cqwak_api_key\x18\x01 \x01(\t\"\\\n\x18\x41uthenticatedUserContext\x12@\n\x04user\x18\x01 \x01(\x0b\x32\x32.qwak.ecosystem.v0.AuthenticatedUnifiedUserContext\"\xfe\x01\n\x1f\x41uthenticatedUnifiedUserContext\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x45\n\x0f\x61\x63\x63ount_details\x18\x05 \x01(\x0b\x32,.qwak.ecosystem.v0.UserContextAccountDetails\x12?\n\x0c\x61\x63\x63ount_role\x18\x01 \x01(\x0e\x32).qwak.administration.user.QwakAccountRole\x12\x42\n\x13\x65nvironment_details\x18\x06 \x01(\x0b\x32%.qwak.ecosystem.v0.EnvironmentDetails\"\xd6\x06\n\x19UserContextAccountDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x65\x66\x61ult_environment_id\x18\x03 \x01(\t\x12\x44\n\x0bpreferences\x18\x05 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\\\n\x11\x65nvironment_by_id\x18\x04 \x03(\x0b\x32\x41.qwak.ecosystem.v0.UserContextAccountDetails.EnvironmentByIdEntry\x12t\n\x1euser_context_environment_by_id\x18\x06 \x03(\x0b\x32L.qwak.ecosystem.v0.UserContextAccountDetails.UserContextEnvironmentByIdEntry\x12\x39\n\x04type\x18\x07 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x08 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\t \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\x12P\n\x14jfrog_tenant_details\x18\n \x01(\x0b\x32\x32.qwak.administration.account.v1.JfrogTenantDetails\x1a]\n\x14\x45nvironmentByIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.qwak.ecosystem.v0.EnvironmentDetails:\x02\x38\x01\x1as\n\x1fUserContextEnvironmentByIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.qwak.ecosystem.v0.UserContextEnvironmentDetails:\x02\x38\x01\"\x1f\n\x1dUserContextEnvironmentDetails\"\xd8\x04\n\x0e\x41\x63\x63ountDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x44\n\x0bpreferences\x18\x03 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x1e\n\x16\x64\x65\x66\x61ult_environment_id\x18\x05 \x01(\t\x12S\n\x12\x65nvironments_by_id\x18\x04 \x03(\x0b\x32\x37.qwak.ecosystem.v0.AccountDetails.EnvironmentsByIdEntry\x12\x39\n\x04type\x18\x06 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x07 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\x08 \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\x12P\n\x14jfrog_tenant_details\x18\t \x01(\x0b\x32\x32.qwak.administration.account.v1.JfrogTenantDetails\x1a^\n\x15\x45nvironmentsByIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.qwak.ecosystem.v0.EnvironmentDetails:\x02\x38\x01\"\x84\x01\n\x12\x45nvironmentDetails\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12T\n\rconfiguration\x18\x03 \x01(\x0b\x32=.qwak.administration.environment.QwakEnvironmentConfiguration\"\xde\x01\n\x0fUserAccountList\x12\x1a\n\x12\x64\x65\x66\x61ult_account_id\x18\x01 \x01(\t\x12L\n\x0e\x61\x63\x63ounts_by_id\x18\x02 \x03(\x0b\x32\x34.qwak.ecosystem.v0.UserAccountList.AccountsByIdEntry\x1a\x61\n\x11\x41\x63\x63ountsByIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.qwak.ecosystem.v0.UserContextAccountDetails:\x02\x38\x01\x42\xb7\x01\n\x1c\x63om.qwak.ai.common.ecosystemP\x01Z\x94\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0b\x06proto3')



_USERNAMEPASSWORDMETHOD = DESCRIPTOR.message_types_by_name['UsernamePasswordMethod']
_QWAKAPIKEYMETHOD = DESCRIPTOR.message_types_by_name['QwakApiKeyMethod']
_AUTHENTICATEDUSERCONTEXT = DESCRIPTOR.message_types_by_name['AuthenticatedUserContext']
_AUTHENTICATEDUNIFIEDUSERCONTEXT = DESCRIPTOR.message_types_by_name['AuthenticatedUnifiedUserContext']
_USERCONTEXTACCOUNTDETAILS = DESCRIPTOR.message_types_by_name['UserContextAccountDetails']
_USERCONTEXTACCOUNTDETAILS_ENVIRONMENTBYIDENTRY = _USERCONTEXTACCOUNTDETAILS.nested_types_by_name['EnvironmentByIdEntry']
_USERCONTEXTACCOUNTDETAILS_USERCONTEXTENVIRONMENTBYIDENTRY = _USERCONTEXTACCOUNTDETAILS.nested_types_by_name['UserContextEnvironmentByIdEntry']
_USERCONTEXTENVIRONMENTDETAILS = DESCRIPTOR.message_types_by_name['UserContextEnvironmentDetails']
_ACCOUNTDETAILS = DESCRIPTOR.message_types_by_name['AccountDetails']
_ACCOUNTDETAILS_ENVIRONMENTSBYIDENTRY = _ACCOUNTDETAILS.nested_types_by_name['EnvironmentsByIdEntry']
_ENVIRONMENTDETAILS = DESCRIPTOR.message_types_by_name['EnvironmentDetails']
_USERACCOUNTLIST = DESCRIPTOR.message_types_by_name['UserAccountList']
_USERACCOUNTLIST_ACCOUNTSBYIDENTRY = _USERACCOUNTLIST.nested_types_by_name['AccountsByIdEntry']
UsernamePasswordMethod = _reflection.GeneratedProtocolMessageType('UsernamePasswordMethod', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEPASSWORDMETHOD,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.UsernamePasswordMethod)
  })
_sym_db.RegisterMessage(UsernamePasswordMethod)

QwakApiKeyMethod = _reflection.GeneratedProtocolMessageType('QwakApiKeyMethod', (_message.Message,), {
  'DESCRIPTOR' : _QWAKAPIKEYMETHOD,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.QwakApiKeyMethod)
  })
_sym_db.RegisterMessage(QwakApiKeyMethod)

AuthenticatedUserContext = _reflection.GeneratedProtocolMessageType('AuthenticatedUserContext', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEDUSERCONTEXT,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.AuthenticatedUserContext)
  })
_sym_db.RegisterMessage(AuthenticatedUserContext)

AuthenticatedUnifiedUserContext = _reflection.GeneratedProtocolMessageType('AuthenticatedUnifiedUserContext', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEDUNIFIEDUSERCONTEXT,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.AuthenticatedUnifiedUserContext)
  })
_sym_db.RegisterMessage(AuthenticatedUnifiedUserContext)

UserContextAccountDetails = _reflection.GeneratedProtocolMessageType('UserContextAccountDetails', (_message.Message,), {

  'EnvironmentByIdEntry' : _reflection.GeneratedProtocolMessageType('EnvironmentByIdEntry', (_message.Message,), {
    'DESCRIPTOR' : _USERCONTEXTACCOUNTDETAILS_ENVIRONMENTBYIDENTRY,
    '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
    # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.UserContextAccountDetails.EnvironmentByIdEntry)
    })
  ,

  'UserContextEnvironmentByIdEntry' : _reflection.GeneratedProtocolMessageType('UserContextEnvironmentByIdEntry', (_message.Message,), {
    'DESCRIPTOR' : _USERCONTEXTACCOUNTDETAILS_USERCONTEXTENVIRONMENTBYIDENTRY,
    '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
    # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.UserContextAccountDetails.UserContextEnvironmentByIdEntry)
    })
  ,
  'DESCRIPTOR' : _USERCONTEXTACCOUNTDETAILS,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.UserContextAccountDetails)
  })
_sym_db.RegisterMessage(UserContextAccountDetails)
_sym_db.RegisterMessage(UserContextAccountDetails.EnvironmentByIdEntry)
_sym_db.RegisterMessage(UserContextAccountDetails.UserContextEnvironmentByIdEntry)

UserContextEnvironmentDetails = _reflection.GeneratedProtocolMessageType('UserContextEnvironmentDetails', (_message.Message,), {
  'DESCRIPTOR' : _USERCONTEXTENVIRONMENTDETAILS,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.UserContextEnvironmentDetails)
  })
_sym_db.RegisterMessage(UserContextEnvironmentDetails)

AccountDetails = _reflection.GeneratedProtocolMessageType('AccountDetails', (_message.Message,), {

  'EnvironmentsByIdEntry' : _reflection.GeneratedProtocolMessageType('EnvironmentsByIdEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNTDETAILS_ENVIRONMENTSBYIDENTRY,
    '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
    # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.AccountDetails.EnvironmentsByIdEntry)
    })
  ,
  'DESCRIPTOR' : _ACCOUNTDETAILS,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.AccountDetails)
  })
_sym_db.RegisterMessage(AccountDetails)
_sym_db.RegisterMessage(AccountDetails.EnvironmentsByIdEntry)

EnvironmentDetails = _reflection.GeneratedProtocolMessageType('EnvironmentDetails', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTDETAILS,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.EnvironmentDetails)
  })
_sym_db.RegisterMessage(EnvironmentDetails)

UserAccountList = _reflection.GeneratedProtocolMessageType('UserAccountList', (_message.Message,), {

  'AccountsByIdEntry' : _reflection.GeneratedProtocolMessageType('AccountsByIdEntry', (_message.Message,), {
    'DESCRIPTOR' : _USERACCOUNTLIST_ACCOUNTSBYIDENTRY,
    '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
    # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.UserAccountList.AccountsByIdEntry)
    })
  ,
  'DESCRIPTOR' : _USERACCOUNTLIST,
  '__module__' : 'qwak.ecosystem.v0.ecosystem_pb2'
  # @@protoc_insertion_point(class_scope:qwak.ecosystem.v0.UserAccountList)
  })
_sym_db.RegisterMessage(UserAccountList)
_sym_db.RegisterMessage(UserAccountList.AccountsByIdEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.qwak.ai.common.ecosystemP\001Z\224\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0'
  _USERCONTEXTACCOUNTDETAILS_ENVIRONMENTBYIDENTRY._options = None
  _USERCONTEXTACCOUNTDETAILS_ENVIRONMENTBYIDENTRY._serialized_options = b'8\001'
  _USERCONTEXTACCOUNTDETAILS_USERCONTEXTENVIRONMENTBYIDENTRY._options = None
  _USERCONTEXTACCOUNTDETAILS_USERCONTEXTENVIRONMENTBYIDENTRY._serialized_options = b'8\001'
  _ACCOUNTDETAILS_ENVIRONMENTSBYIDENTRY._options = None
  _ACCOUNTDETAILS_ENVIRONMENTSBYIDENTRY._serialized_options = b'8\001'
  _USERACCOUNTLIST_ACCOUNTSBYIDENTRY._options = None
  _USERACCOUNTLIST_ACCOUNTSBYIDENTRY._serialized_options = b'8\001'
  _USERNAMEPASSWORDMETHOD._serialized_start=353
  _USERNAMEPASSWORDMETHOD._serialized_end=413
  _QWAKAPIKEYMETHOD._serialized_start=415
  _QWAKAPIKEYMETHOD._serialized_end=455
  _AUTHENTICATEDUSERCONTEXT._serialized_start=457
  _AUTHENTICATEDUSERCONTEXT._serialized_end=549
  _AUTHENTICATEDUNIFIEDUSERCONTEXT._serialized_start=552
  _AUTHENTICATEDUNIFIEDUSERCONTEXT._serialized_end=806
  _USERCONTEXTACCOUNTDETAILS._serialized_start=809
  _USERCONTEXTACCOUNTDETAILS._serialized_end=1663
  _USERCONTEXTACCOUNTDETAILS_ENVIRONMENTBYIDENTRY._serialized_start=1453
  _USERCONTEXTACCOUNTDETAILS_ENVIRONMENTBYIDENTRY._serialized_end=1546
  _USERCONTEXTACCOUNTDETAILS_USERCONTEXTENVIRONMENTBYIDENTRY._serialized_start=1548
  _USERCONTEXTACCOUNTDETAILS_USERCONTEXTENVIRONMENTBYIDENTRY._serialized_end=1663
  _USERCONTEXTENVIRONMENTDETAILS._serialized_start=1665
  _USERCONTEXTENVIRONMENTDETAILS._serialized_end=1696
  _ACCOUNTDETAILS._serialized_start=1699
  _ACCOUNTDETAILS._serialized_end=2299
  _ACCOUNTDETAILS_ENVIRONMENTSBYIDENTRY._serialized_start=2205
  _ACCOUNTDETAILS_ENVIRONMENTSBYIDENTRY._serialized_end=2299
  _ENVIRONMENTDETAILS._serialized_start=2302
  _ENVIRONMENTDETAILS._serialized_end=2434
  _USERACCOUNTLIST._serialized_start=2437
  _USERACCOUNTLIST._serialized_end=2659
  _USERACCOUNTLIST_ACCOUNTSBYIDENTRY._serialized_start=2562
  _USERACCOUNTLIST_ACCOUNTSBYIDENTRY._serialized_end=2659
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/sql_engine_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDqwak/administration/runtime_configuration/v0/sql_engine_config.proto\x12>qwak.administration.runtime_configuration.v0.sql_engine_config\"\xab\x02\n\x16SqlEngineConfiguration\x12\x80\x01\n\x1f\x61thena_sql_engine_configuration\x18\x01 \x01(\x0b\x32U.qwak.administration.runtime_configuration.v0.sql_engine_config.AthenaSqlEngineConfigH\x00\x12\x85\x01\n\"big_query_sql_engine_configuration\x18\x02 \x01(\x0b\x32W.qwak.administration.runtime_configuration.v0.sql_engine_config.BigQuerySqlEngineConfigH\x00\x42\x06\n\x04type\"?\n\x15\x41thenaSqlEngineConfig\x12\x13\n\x0b\x65xternal_id\x18\x01 \x01(\t\x12\x11\n\tworkgroup\x18\x02 \x01(\t\"\x19\n\x17\x42igQuerySqlEngineConfigB\xde\x01\n7com.jfrog.ml.runtime_configuration.v0.sql_engine_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')



_SQLENGINECONFIGURATION = DESCRIPTOR.message_types_by_name['SqlEngineConfiguration']
_ATHENASQLENGINECONFIG = DESCRIPTOR.message_types_by_name['AthenaSqlEngineConfig']
_BIGQUERYSQLENGINECONFIG = DESCRIPTOR.message_types_by_name['BigQuerySqlEngineConfig']
SqlEngineConfiguration = _reflection.GeneratedProtocolMessageType('SqlEngineConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SQLENGINECONFIGURATION,
  '__module__' : 'qwak.administration.runtime_configuration.v0.sql_engine_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.sql_engine_config.SqlEngineConfiguration)
  })
_sym_db.RegisterMessage(SqlEngineConfiguration)

AthenaSqlEngineConfig = _reflection.GeneratedProtocolMessageType('AthenaSqlEngineConfig', (_message.Message,), {
  'DESCRIPTOR' : _ATHENASQLENGINECONFIG,
  '__module__' : 'qwak.administration.runtime_configuration.v0.sql_engine_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.sql_engine_config.AthenaSqlEngineConfig)
  })
_sym_db.RegisterMessage(AthenaSqlEngineConfig)

BigQuerySqlEngineConfig = _reflection.GeneratedProtocolMessageType('BigQuerySqlEngineConfig', (_message.Message,), {
  'DESCRIPTOR' : _BIGQUERYSQLENGINECONFIG,
  '__module__' : 'qwak.administration.runtime_configuration.v0.sql_engine_config_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.sql_engine_config.BigQuerySqlEngineConfig)
  })
_sym_db.RegisterMessage(BigQuerySqlEngineConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.jfrog.ml.runtime_configuration.v0.sql_engine_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _SQLENGINECONFIGURATION._serialized_start=137
  _SQLENGINECONFIGURATION._serialized_end=436
  _ATHENASQLENGINECONFIG._serialized_start=438
  _ATHENASQLENGINECONFIG._serialized_end=501
  _BIGQUERYSQLENGINECONFIG._serialized_start=503
  _BIGQUERYSQLENGINECONFIG._serialized_end=528
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.execution.v1.jobs.job_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ApplyJobRecordRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORD_FIELD_NUMBER: builtins.int
    @property
    def job_record(self) -> qwak.execution.v1.jobs.job_pb2.JobRecord:
        """a Job Record to create or replace"""
    def __init__(
        self,
        *,
        job_record: qwak.execution.v1.jobs.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> None: ...

global___ApplyJobRecordRequest = ApplyJobRecordRequest

class ApplyJobRecordResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ApplyJobRecordResponse = ApplyJobRecordResponse

class InitPaginationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """the featureset id for which to start a pagination"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___InitPaginationRequest = InitPaginationRequest

class InitPaginationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    MAX_RECORD_ID_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """Number of records found for this Featureset at the time of querying
    this is used mainly by the client to plan things like number of pages etc.
    """
    max_record_id: builtins.int
    """the current highest record id for this FS. this is the anchor
    to use on subsequent requests if the caller wants to achieve
    a view of a static list
    """
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        max_record_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_record_id", b"max_record_id", "record_count", b"record_count"]) -> None: ...

global___InitPaginationResponse = InitPaginationResponse

class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    MAX_RECORD_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """featureset id"""
    page_size: builtins.int
    """The page size to use for the response - the number of results in the response
    is the minimum of the page_size and number of matching rows.
    - a negative value means all results will be returned (in that case page_number is ignored)
    """
    page_number: builtins.int
    """The page number to use"""
    max_record_id: builtins.int
    """The max record id to use as anchor - this is the value returned from InitPagination"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        max_record_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id", "max_record_id", b"max_record_id", "page_number", b"page_number", "page_size", b"page_size"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def job_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.jobs.job_pb2.JobRecord]:
        """All rows, sorted by the job record start time (event time)"""
    def __init__(
        self,
        *,
        job_records: collections.abc.Iterable[qwak.execution.v1.jobs.job_pb2.JobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_records", b"job_records"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

class InitPaginationByExecutionIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """the execution id"""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___InitPaginationByExecutionIdRequest = InitPaginationByExecutionIdRequest

class InitPaginationByExecutionIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    MAX_RECORD_ID_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """Number of records found for this Featureset and execution at the time of querying.
    this is used mainly by the client to plan things like number of pages etc.
    """
    max_record_id: builtins.int
    """the current highest record id for this FS. this is the anchor
    to use on subsequent requests if the caller wants to achieve
    a view of a static list
    """
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        max_record_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_record_id", b"max_record_id", "record_count", b"record_count"]) -> None: ...

global___InitPaginationByExecutionIdResponse = InitPaginationByExecutionIdResponse

class ListJobsByExecutionIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    MAX_RECORD_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """execution id"""
    page_size: builtins.int
    """The page size to use for the response - the number of results in the response
    is the minimum of the page_size and number of matching rows.
    - a negative value means all results will be returned (in that case page_number is ignored)
    """
    page_number: builtins.int
    """The page number to use"""
    max_record_id: builtins.int
    """The max record id to use as anchor - this is the value returned from InitPagination"""
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        max_record_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id", "max_record_id", b"max_record_id", "page_number", b"page_number", "page_size", b"page_size"]) -> None: ...

global___ListJobsByExecutionIdRequest = ListJobsByExecutionIdRequest

class ListJobsByExecutionIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def job_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.jobs.job_pb2.JobRecord]:
        """All rows, sorted by the job record start time (event time)"""
    def __init__(
        self,
        *,
        job_records: collections.abc.Iterable[qwak.execution.v1.jobs.job_pb2.JobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_records", b"job_records"]) -> None: ...

global___ListJobsByExecutionIdResponse = ListJobsByExecutionIdResponse

class DeleteFeaturesetJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """The featureset id"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___DeleteFeaturesetJobsRequest = DeleteFeaturesetJobsRequest

class DeleteFeaturesetJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_JOB_RECORD_COUNT_FIELD_NUMBER: builtins.int
    deleted_job_record_count: builtins.int
    def __init__(
        self,
        *,
        deleted_job_record_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_job_record_count", b"deleted_job_record_count"]) -> None: ...

global___DeleteFeaturesetJobsResponse = DeleteFeaturesetJobsResponse

class GetLatestSuccessfulJobByFeaturesetIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___GetLatestSuccessfulJobByFeaturesetIdRequest = GetLatestSuccessfulJobByFeaturesetIdRequest

class GetLatestSuccessfulJobByFeaturesetIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORD_FIELD_NUMBER: builtins.int
    @property
    def job_record(self) -> qwak.execution.v1.jobs.job_pb2.JobRecord: ...
    def __init__(
        self,
        *,
        job_record: qwak.execution.v1.jobs.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_record", b"job_record", "job_record_resp", b"job_record_resp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_record", b"job_record", "job_record_resp", b"job_record_resp"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["job_record_resp", b"job_record_resp"]) -> typing_extensions.Literal["job_record"] | None: ...

global___GetLatestSuccessfulJobByFeaturesetIdResponse = GetLatestSuccessfulJobByFeaturesetIdResponse

class GetAllFeaturesetLatestSuccessfulJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetAllFeaturesetLatestSuccessfulJobsRequest = GetAllFeaturesetLatestSuccessfulJobsRequest

class GetAllFeaturesetLatestSuccessfulJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def job_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.jobs.job_pb2.JobRecord]:
        """all latest requested jobs"""
    def __init__(
        self,
        *,
        job_records: collections.abc.Iterable[qwak.execution.v1.jobs.job_pb2.JobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_records", b"job_records"]) -> None: ...

global___GetAllFeaturesetLatestSuccessfulJobsResponse = GetAllFeaturesetLatestSuccessfulJobsResponse

class GetAllFeaturesetJobsSummariesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOWER_TIME_BOUND_FIELD_NUMBER: builtins.int
    UPPER_TIME_BOUND_FIELD_NUMBER: builtins.int
    @property
    def lower_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Summary lower time bound.
        applied on processing start_time column.
        """
    @property
    def upper_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        lower_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        upper_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "upper_bound", b"upper_bound", "upper_time_bound", b"upper_time_bound"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "upper_bound", b"upper_bound", "upper_time_bound", b"upper_time_bound"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["upper_bound", b"upper_bound"]) -> typing_extensions.Literal["upper_time_bound"] | None: ...

global___GetAllFeaturesetJobsSummariesRequest = GetAllFeaturesetJobsSummariesRequest

class GetAllFeaturesetJobsSummariesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_SUMMARIES_FIELD_NUMBER: builtins.int
    @property
    def jobs_summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeaturesetJobsSummary]:
        """Job summaries per featureset for the entire environment"""
    def __init__(
        self,
        *,
        jobs_summaries: collections.abc.Iterable[global___FeaturesetJobsSummary] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs_summaries", b"jobs_summaries"]) -> None: ...

global___GetAllFeaturesetJobsSummariesResponse = GetAllFeaturesetJobsSummariesResponse

class FeaturesetJobsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    TOTAL_AFFECTED_ROWS_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """Featureset Id"""
    total_affected_rows: builtins.int
    """Number of affected rows"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        total_affected_rows: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id", "total_affected_rows", b"total_affected_rows"]) -> None: ...

global___FeaturesetJobsSummary = FeaturesetJobsSummary

class GetJobsSummaryByExecutionIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetJobsSummaryByExecutionIdRequest = GetJobsSummaryByExecutionIdRequest

class GetJobsSummaryByExecutionIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    JOB_COUNT_FIELD_NUMBER: builtins.int
    TOTAL_AFFECTED_ROWS_FIELD_NUMBER: builtins.int
    FIRST_JOB_RECORD_FIELD_NUMBER: builtins.int
    LAST_JOB_RECORD_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    job_count: builtins.int
    total_affected_rows: builtins.int
    @property
    def first_job_record(self) -> qwak.execution.v1.jobs.job_pb2.JobRecord: ...
    @property
    def last_job_record(self) -> qwak.execution.v1.jobs.job_pb2.JobRecord: ...
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
        job_count: builtins.int = ...,
        total_affected_rows: builtins.int = ...,
        first_job_record: qwak.execution.v1.jobs.job_pb2.JobRecord | None = ...,
        last_job_record: qwak.execution.v1.jobs.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["first_job_record", b"first_job_record", "last_job_record", b"last_job_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id", "first_job_record", b"first_job_record", "job_count", b"job_count", "last_job_record", b"last_job_record", "total_affected_rows", b"total_affected_rows"]) -> None: ...

global___GetJobsSummaryByExecutionIdResponse = GetJobsSummaryByExecutionIdResponse

class GetJobSummariesByExecutionIdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_IDS_FIELD_NUMBER: builtins.int
    @property
    def execution_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        execution_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_ids", b"execution_ids"]) -> None: ...

global___GetJobSummariesByExecutionIdsRequest = GetJobSummariesByExecutionIdsRequest

class GetJobSummariesByExecutionIdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_SUMMARIES_FIELD_NUMBER: builtins.int
    @property
    def execution_summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExecutionJobsSummary]: ...
    def __init__(
        self,
        *,
        execution_summaries: collections.abc.Iterable[global___ExecutionJobsSummary] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_summaries", b"execution_summaries"]) -> None: ...

global___GetJobSummariesByExecutionIdsResponse = GetJobSummariesByExecutionIdsResponse

class ExecutionJobsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    JOB_COUNT_FIELD_NUMBER: builtins.int
    TOTAL_AFFECTED_ROWS_FIELD_NUMBER: builtins.int
    FIRST_JOB_RECORD_FIELD_NUMBER: builtins.int
    LAST_JOB_RECORD_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    """execution ID"""
    job_count: builtins.int
    """number of jobs within this execution"""
    total_affected_rows: builtins.int
    """total affected rows by all jobs known for this execution"""
    @property
    def first_job_record(self) -> qwak.execution.v1.jobs.job_pb2.JobRecord: ...
    @property
    def last_job_record(self) -> qwak.execution.v1.jobs.job_pb2.JobRecord: ...
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
        job_count: builtins.int = ...,
        total_affected_rows: builtins.int = ...,
        first_job_record: qwak.execution.v1.jobs.job_pb2.JobRecord | None = ...,
        last_job_record: qwak.execution.v1.jobs.job_pb2.JobRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["first_job_record", b"first_job_record", "first_job_record_opt", b"first_job_record_opt", "last_job_record", b"last_job_record", "last_job_record_opt", b"last_job_record_opt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id", "first_job_record", b"first_job_record", "first_job_record_opt", b"first_job_record_opt", "job_count", b"job_count", "last_job_record", b"last_job_record", "last_job_record_opt", b"last_job_record_opt", "total_affected_rows", b"total_affected_rows"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["first_job_record_opt", b"first_job_record_opt"]) -> typing_extensions.Literal["first_job_record"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["last_job_record_opt", b"last_job_record_opt"]) -> typing_extensions.Literal["last_job_record"] | None: ...

global___ExecutionJobsSummary = ExecutionJobsSummary



from __future__ import annotations

from abc import ABC, abstractmethod

from qwak.inner.build_config.build_config_v1 import BuildConfigV1
from qwak.inner.build_logic.interface.build_phase import BuildPhase
from qwak.inner.build_logic.interface.context_interface import Context
from qwak.inner.build_logic.interface.build_logger_interface import BuildLogger


class Step(ABC):
    context: Context
    config: BuildConfigV1
    build_logger: BuildLogger
    build_phase: BuildPhase

    @abstractmethod
    def description(self) -> str:
        pass

    @abstractmethod
    def execute(self) -> None:
        pass

    def set_logger(self, build_logger: BuildLogger) -> None:
        self.build_logger = build_logger



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/jobs/job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.jobs import job_pb2 as qwak_dot_feature__store_dot_jobs_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/feature_store/jobs/job_service.proto\x12\x17qwak.feature.store.jobs\x1a!qwak/feature_store/jobs/job.proto\"\x91\x01\n\x0f\x41pplyJobRequest\x12\x36\n\njob_record\x18\x01 \x01(\x0b\x32\".qwak.feature.store.jobs.JobRecord\x12\x11\n\tlogs_path\x18\x02 \x01(\t\x12\x12\n\npartner_id\x18\x03 \x01(\t\x12\x1f\n\x17\x65rror_technical_details\x18\x04 \x01(\t\"*\n\x10\x41pplyJobResponse\x12\x16\n\x0ejob_running_id\x18\x01 \x01(\x03\"1\n\x15InitPaginationRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"?\n\x16InitPaginationResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x05\x12\x0f\n\x07last_id\x18\x02 \x01(\x03\"e\n\x0fListJobsRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x10\n\x08\x61\x66ter_id\x18\x04 \x01(\x03\"M\n\x10ListJobsResponse\x12\x39\n\x04jobs\x18\x01 \x03(\x0b\x32+.qwak.feature.store.jobs.ElaborateJobRecord\"#\n\x11GetJobLogsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\".\n\x12GetJobLogsResponse\x12\x18\n\x10logs_folder_path\x18\x01 \x01(\t\"M\n\x1dGetLatestSuccessfulJobRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x12\n\npartner_id\x18\x02 \x01(\t\"i\n\x1eGetLatestSuccessfulJobResponse\x12\x38\n\x03job\x18\x01 \x01(\x0b\x32+.qwak.feature.store.jobs.ElaborateJobRecord\x12\r\n\x05\x66ound\x18\x02 \x01(\x08\"7\n\x1b\x44\x65leteFeatureSetJobsRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"A\n\x1c\x44\x65leteFeatureSetJobsResponse\x12!\n\x19\x64\x65leted_job_records_count\x18\x01 \x01(\x05\x32\xba\x05\n\nJobService\x12_\n\x08\x41pplyJob\x12(.qwak.feature.store.jobs.ApplyJobRequest\x1a).qwak.feature.store.jobs.ApplyJobResponse\x12q\n\x0eInitPagination\x12..qwak.feature.store.jobs.InitPaginationRequest\x1a/.qwak.feature.store.jobs.InitPaginationResponse\x12_\n\x08ListJobs\x12(.qwak.feature.store.jobs.ListJobsRequest\x1a).qwak.feature.store.jobs.ListJobsResponse\x12\x65\n\nGetJobLogs\x12*.qwak.feature.store.jobs.GetJobLogsRequest\x1a+.qwak.feature.store.jobs.GetJobLogsResponse\x12\x89\x01\n\x16GetLatestSuccessfulJob\x12\x36.qwak.feature.store.jobs.GetLatestSuccessfulJobRequest\x1a\x37.qwak.feature.store.jobs.GetLatestSuccessfulJobResponse\x12\x83\x01\n\x14\x44\x65leteFeatureSetJobs\x12\x34.qwak.feature.store.jobs.DeleteFeatureSetJobsRequest\x1a\x35.qwak.feature.store.jobs.DeleteFeatureSetJobsResponseB:\n\"com.qwak.ai.feature.store.jobs.apiP\x01Z\x12qwak/fsjobs;fsjobsb\x06proto3')



_APPLYJOBREQUEST = DESCRIPTOR.message_types_by_name['ApplyJobRequest']
_APPLYJOBRESPONSE = DESCRIPTOR.message_types_by_name['ApplyJobResponse']
_INITPAGINATIONREQUEST = DESCRIPTOR.message_types_by_name['InitPaginationRequest']
_INITPAGINATIONRESPONSE = DESCRIPTOR.message_types_by_name['InitPaginationResponse']
_LISTJOBSREQUEST = DESCRIPTOR.message_types_by_name['ListJobsRequest']
_LISTJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ListJobsResponse']
_GETJOBLOGSREQUEST = DESCRIPTOR.message_types_by_name['GetJobLogsRequest']
_GETJOBLOGSRESPONSE = DESCRIPTOR.message_types_by_name['GetJobLogsResponse']
_GETLATESTSUCCESSFULJOBREQUEST = DESCRIPTOR.message_types_by_name['GetLatestSuccessfulJobRequest']
_GETLATESTSUCCESSFULJOBRESPONSE = DESCRIPTOR.message_types_by_name['GetLatestSuccessfulJobResponse']
_DELETEFEATURESETJOBSREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureSetJobsRequest']
_DELETEFEATURESETJOBSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureSetJobsResponse']
ApplyJobRequest = _reflection.GeneratedProtocolMessageType('ApplyJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYJOBREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ApplyJobRequest)
  })
_sym_db.RegisterMessage(ApplyJobRequest)

ApplyJobResponse = _reflection.GeneratedProtocolMessageType('ApplyJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYJOBRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ApplyJobResponse)
  })
_sym_db.RegisterMessage(ApplyJobResponse)

InitPaginationRequest = _reflection.GeneratedProtocolMessageType('InitPaginationRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.InitPaginationRequest)
  })
_sym_db.RegisterMessage(InitPaginationRequest)

InitPaginationResponse = _reflection.GeneratedProtocolMessageType('InitPaginationResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.InitPaginationResponse)
  })
_sym_db.RegisterMessage(InitPaginationResponse)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

GetJobLogsRequest = _reflection.GeneratedProtocolMessageType('GetJobLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBLOGSREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetJobLogsRequest)
  })
_sym_db.RegisterMessage(GetJobLogsRequest)

GetJobLogsResponse = _reflection.GeneratedProtocolMessageType('GetJobLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBLOGSRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetJobLogsResponse)
  })
_sym_db.RegisterMessage(GetJobLogsResponse)

GetLatestSuccessfulJobRequest = _reflection.GeneratedProtocolMessageType('GetLatestSuccessfulJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTSUCCESSFULJOBREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetLatestSuccessfulJobRequest)
  })
_sym_db.RegisterMessage(GetLatestSuccessfulJobRequest)

GetLatestSuccessfulJobResponse = _reflection.GeneratedProtocolMessageType('GetLatestSuccessfulJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTSUCCESSFULJOBRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetLatestSuccessfulJobResponse)
  })
_sym_db.RegisterMessage(GetLatestSuccessfulJobResponse)

DeleteFeatureSetJobsRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETJOBSREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.DeleteFeatureSetJobsRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureSetJobsRequest)

DeleteFeatureSetJobsResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETJOBSRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.DeleteFeatureSetJobsResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureSetJobsResponse)

_JOBSERVICE = DESCRIPTOR.services_by_name['JobService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.qwak.ai.feature.store.jobs.apiP\001Z\022qwak/fsjobs;fsjobs'
  _APPLYJOBREQUEST._serialized_start=106
  _APPLYJOBREQUEST._serialized_end=251
  _APPLYJOBRESPONSE._serialized_start=253
  _APPLYJOBRESPONSE._serialized_end=295
  _INITPAGINATIONREQUEST._serialized_start=297
  _INITPAGINATIONREQUEST._serialized_end=346
  _INITPAGINATIONRESPONSE._serialized_start=348
  _INITPAGINATIONRESPONSE._serialized_end=411
  _LISTJOBSREQUEST._serialized_start=413
  _LISTJOBSREQUEST._serialized_end=514
  _LISTJOBSRESPONSE._serialized_start=516
  _LISTJOBSRESPONSE._serialized_end=593
  _GETJOBLOGSREQUEST._serialized_start=595
  _GETJOBLOGSREQUEST._serialized_end=630
  _GETJOBLOGSRESPONSE._serialized_start=632
  _GETJOBLOGSRESPONSE._serialized_end=678
  _GETLATESTSUCCESSFULJOBREQUEST._serialized_start=680
  _GETLATESTSUCCESSFULJOBREQUEST._serialized_end=757
  _GETLATESTSUCCESSFULJOBRESPONSE._serialized_start=759
  _GETLATESTSUCCESSFULJOBRESPONSE._serialized_end=864
  _DELETEFEATURESETJOBSREQUEST._serialized_start=866
  _DELETEFEATURESETJOBSREQUEST._serialized_end=921
  _DELETEFEATURESETJOBSRESPONSE._serialized_start=923
  _DELETEFEATURESETJOBSRESPONSE._serialized_end=988
  _JOBSERVICE._serialized_start=991
  _JOBSERVICE._serialized_end=1689
# @@protoc_insertion_point(module_scope)



import grpc
from _qwak_proto.qwak.secret_service.secret_service_pb2 import (
    DeleteSecretRequest,
    DeleteSecretResponse,
    GetSecretRequest,
    GetSecretResponse,
    SetSecretRequest,
    SetSecretResponse,
)
from _qwak_proto.qwak.secret_service.secret_service_pb2_grpc import (
    SecretServiceServicer,
)


class SecretServiceMock(SecretServiceServicer):
    secrets = {}

    def SetSecret(self, request: SetSecretRequest, context) -> SetSecretResponse:
        """Set a value for a secret"""
        self.secrets[request.name] = request.value
        return SetSecretResponse()

    def GetSecret(self, request: GetSecretRequest, context) -> GetSecretResponse:
        """Get a secret value"""
        if request.name in self.secrets:
            return GetSecretResponse(
                name=request.name, value=self.secrets[request.name]
            )
        context.set_code(grpc.StatusCode.NOT_FOUND)
        context.set_details("Secret not found")
        return GetSecretResponse()

    def DeleteSecret(
        self, request: DeleteSecretRequest, context
    ) -> DeleteSecretResponse:
        """Remove a secret"""
        if request.name in self.secrets:
            del self.secrets[request.name]
            return DeleteSecretResponse()
        context.set_code(grpc.StatusCode.NOT_FOUND)
        context.set_details("Secret not found")
        return DeleteSecretResponse()



import socket
from contextlib import closing


def find_free_port():
    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
        s.bind(("", 0))
        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        return s.getsockname()[1]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/creds/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=qwak/administration/runtime_configuration/v0/creds/auth.proto\x12\x37qwak.administration.runtime_configuration.v0.creds.auth\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\"\xc1\x01\n\tBasicAuth\x12Y\n\x08username\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRef\x12Y\n\x08password\x18\x02 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefB\xe3\x01\n0com.jfrog.ml.runtime_configuration.v0.creds.authP\x01Z\xac\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/creds;runtime_configuration_v0_credsb\x06proto3')



_BASICAUTH = DESCRIPTOR.message_types_by_name['BasicAuth']
BasicAuth = _reflection.GeneratedProtocolMessageType('BasicAuth', (_message.Message,), {
  'DESCRIPTOR' : _BASICAUTH,
  '__module__' : 'qwak.administration.runtime_configuration.v0.creds.auth_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.runtime_configuration.v0.creds.auth.BasicAuth)
  })
_sym_db.RegisterMessage(BasicAuth)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n0com.jfrog.ml.runtime_configuration.v0.creds.authP\001Z\254\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/creds;runtime_configuration_v0_creds'
  _BASICAUTH._serialized_start=188
  _BASICAUTH._serialized_end=381
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/preferences.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.account.v1 import personalization_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_personalization__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0qwak/administration/account/v1/preferences.proto\x12\x1bqwak.administration.account\x1a\x34qwak/administration/account/v1/personalization.proto\"b\n\x12\x41\x63\x63ountPreferences\x12L\n\x0fpersonalization\x18\x02 \x01(\x0b\x32\x33.qwak.administration.account.AccountPersonalizationB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')



_ACCOUNTPREFERENCES = DESCRIPTOR.message_types_by_name['AccountPreferences']
AccountPreferences = _reflection.GeneratedProtocolMessageType('AccountPreferences', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPREFERENCES,
  '__module__' : 'qwak.administration.account.v1.preferences_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.AccountPreferences)
  })
_sym_db.RegisterMessage(AccountPreferences)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _ACCOUNTPREFERENCES._serialized_start=135
  _ACCOUNTPREFERENCES._serialized_end=233
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import qwak.administration.authenticated_user.v1.credentials_pb2
import qwak.administration.authenticated_user.v1.details_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDetailsRequest = GetDetailsRequest

class GetDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> qwak.administration.authenticated_user.v1.details_pb2.UserDetails:
        """The authenticated user details"""
    @property
    def environment(self) -> qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails:
        """The authenticated user environment"""
    def __init__(
        self,
        *,
        user: qwak.administration.authenticated_user.v1.details_pb2.UserDetails | None = ...,
        environment: qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment", "user", b"user"]) -> None: ...

global___GetDetailsResponse = GetDetailsResponse

class GetEnvironmentDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetEnvironmentDetailsRequest = GetEnvironmentDetailsRequest

class GetEnvironmentDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails:
        """The authenticated user environment"""
    def __init__(
        self,
        *,
        environment: qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___GetEnvironmentDetailsResponse = GetEnvironmentDetailsResponse

class GetCloudCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> None: ...

global___GetCloudCredentialsRequest = GetCloudCredentialsRequest

class GetCloudCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def cloud_credentials(self) -> qwak.administration.authenticated_user.v1.credentials_pb2.CloudCredentials:
        """The credentials of the environment in the cloud provider"""
    def __init__(
        self,
        *,
        cloud_credentials: qwak.administration.authenticated_user.v1.credentials_pb2.CloudCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_credentials", b"cloud_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_credentials", b"cloud_credentials"]) -> None: ...

global___GetCloudCredentialsResponse = GetCloudCredentialsResponse



from typing import List


def _generate_new_col(col_name: str, duplicate_cols_dict: dict):
    """
    Generate column without leading feature set name.
    Args:
        col_name: the target column name
        duplicate_cols_dict: duplicate features dictionary
    Returns list of the new columns
    """
    feature_full_name: List[str] = col_name.split(".")
    if len(feature_full_name) != 2:
        return col_name
    elif len(feature_full_name) == 2 and duplicate_cols_dict[feature_full_name[1]] > 1:
        return col_name
    elif len(feature_full_name) == 2 and duplicate_cols_dict[feature_full_name[1]] == 1:
        return feature_full_name[1]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SearchFilter(google.protobuf.message.Message):
    """Represent a filter on logs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_TEXT_FILTER_FIELD_NUMBER: builtins.int
    AND_OPERATOR_FILTER_FIELD_NUMBER: builtins.int
    LOG_EMITTING_TIME_FILTER_FIELD_NUMBER: builtins.int
    @property
    def log_text_filter(self) -> global___LogText:
        """filter by log message"""
    @property
    def and_operator_filter(self) -> global___AndOperatorFilter:
        """Concat filters by AND operation"""
    @property
    def log_emitting_time_filter(self) -> global___LogTimeFilter:
        """Filter by emitting time of logs"""
    def __init__(
        self,
        *,
        log_text_filter: global___LogText | None = ...,
        and_operator_filter: global___AndOperatorFilter | None = ...,
        log_emitting_time_filter: global___LogTimeFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["and_operator_filter", b"and_operator_filter", "filter", b"filter", "log_emitting_time_filter", b"log_emitting_time_filter", "log_text_filter", b"log_text_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["and_operator_filter", b"and_operator_filter", "filter", b"filter", "log_emitting_time_filter", b"log_emitting_time_filter", "log_text_filter", b"log_text_filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["filter", b"filter"]) -> typing_extensions.Literal["log_text_filter", "and_operator_filter", "log_emitting_time_filter"] | None: ...

global___SearchFilter = SearchFilter

class LogText(google.protobuf.message.Message):
    """Filter by the text of the log"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINS_FIELD_NUMBER: builtins.int
    contains: builtins.str
    """Contains filter - matches parts of text"""
    def __init__(
        self,
        *,
        contains: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["contains", b"contains"]) -> None: ...

global___LogText = LogText

class LogTimeFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AFTER_TIME_FIELD_NUMBER: builtins.int
    BEFORE_TIME_FIELD_NUMBER: builtins.int
    @property
    def after_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Filter log emitted after a timestamp"""
    @property
    def before_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Filter log emitted before a timestamp"""
    def __init__(
        self,
        *,
        after_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        before_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["after_time", b"after_time", "before_time", b"before_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_time", b"after_time", "before_time", b"before_time"]) -> None: ...

global___LogTimeFilter = LogTimeFilter

class AndOperatorFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_FILTERS_FIELD_NUMBER: builtins.int
    @property
    def search_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchFilter]: ...
    def __init__(
        self,
        *,
        search_filters: collections.abc.Iterable[global___SearchFilter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["search_filters", b"search_filters"]) -> None: ...

global___AndOperatorFilter = AndOperatorFilter



from dataclasses import dataclass, field
from datetime import datetime
from enum import Enum

from _qwak_proto.qwak.batch_job.v1.batch_job_service_pb2 import (
    TaskExecutionDetails as TaskExecutionDetailsProto,
)


class TaskStatus(Enum):
    UNDEFINED_BATCH_TASK_STATUS = 0
    BATCH_TASK_COMMITTED_STATUS = 1
    BATCH_TASK_PENDING_START_STATUS = 2
    BATCH_TASK_RUNNING_STATUS = 3
    BATCH_TASK_FINISHED_STATUS = 4
    BATCH_TASK_FAILED_STATUS = 5
    BATCH_TASK_CANCELLED_STATUS = 6
    BATCH_TASK_TIMEOUT_STATUS = 7


@dataclass
class Task:
    task_id: str = field(default=None)
    task_status: TaskStatus = field(default=TaskStatus.UNDEFINED_BATCH_TASK_STATUS)
    start_time: datetime = field(default=datetime.now())
    end_time: datetime = field(default=datetime.now())
    filename: str = field(default=None)

    @staticmethod
    def from_proto(task_execution_details_proto: TaskExecutionDetailsProto):
        return Task(
            task_id=task_execution_details_proto.task_id,
            task_status=TaskStatus(task_execution_details_proto.status),
            start_time=datetime.fromtimestamp(
                task_execution_details_proto.start_time.seconds
                + task_execution_details_proto.start_time.nanos / 1e9
            ),
            end_time=datetime.fromtimestamp(
                task_execution_details_proto.end_time.seconds
                + task_execution_details_proto.end_time.nanos / 1e9
            ),
            filename=task_execution_details_proto.filename,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.sources import data_source_pb2 as qwak_dot_feature__store_dot_sources_dot_data__source__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/feature_store/sources/data_source_service.proto\x12\x1aqwak.feature.store.sources\x1a,qwak/feature_store/sources/data_source.proto\"_\n\x17\x43reateDataSourceRequest\x12\x44\n\x10\x64\x61ta_source_spec\x18\x01 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"W\n\x18\x43reateDataSourceResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"w\n\x17UpdateDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x44\n\x10\x64\x61ta_source_spec\x18\x02 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"W\n\x18UpdateDataSourceResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"1\n\x17\x44\x65leteDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"2\n\x18GetDataSourceByIdRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"X\n\x19GetDataSourceByIdResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"6\n\x1aGetDataSourceByNameRequest\x12\x18\n\x10\x64\x61ta_source_name\x18\x01 \x01(\t\"Z\n\x1bGetDataSourceByNameResponse\x12;\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32&.qwak.feature.store.sources.DataSource\"\x18\n\x16ListDataSourcesRequest\"W\n\x17ListDataSourcesResponse\x12<\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32&.qwak.feature.store.sources.DataSource\"Q\n CreateDataSourceUploadURLRequest\x12\x18\n\x10\x64\x61ta_source_name\x18\x01 \x01(\t\x12\x13\n\x0bobject_name\x18\x02 \x01(\t\"7\n!CreateDataSourceUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t2\xd5\x08\n\x11\x44\x61taSourceService\x12}\n\x10\x43reateDataSource\x12\x33.qwak.feature.store.sources.CreateDataSourceRequest\x1a\x34.qwak.feature.store.sources.CreateDataSourceResponse\x12}\n\x10UpdateDataSource\x12\x33.qwak.feature.store.sources.UpdateDataSourceRequest\x1a\x34.qwak.feature.store.sources.UpdateDataSourceResponse\x12}\n\x10\x44\x65leteDataSource\x12\x33.qwak.feature.store.sources.DeleteDataSourceRequest\x1a\x34.qwak.feature.store.sources.DeleteDataSourceResponse\x12\x80\x01\n\x11GetDataSourceById\x12\x34.qwak.feature.store.sources.GetDataSourceByIdRequest\x1a\x35.qwak.feature.store.sources.GetDataSourceByIdResponse\x12\x86\x01\n\x13GetDataSourceByName\x12\x36.qwak.feature.store.sources.GetDataSourceByNameRequest\x1a\x37.qwak.feature.store.sources.GetDataSourceByNameResponse\x12z\n\x0fListDataSources\x12\x32.qwak.feature.store.sources.ListDataSourcesRequest\x1a\x33.qwak.feature.store.sources.ListDataSourcesResponse\x12\x9d\x01\n\x19\x43reateDataSourceUploadURL\x12<.qwak.feature.store.sources.CreateDataSourceUploadURLRequest\x1a=.qwak.feature.store.sources.CreateDataSourceUploadURLResponse\"\x03\x88\x02\x01\x12\x9a\x01\n\x1b\x43reateDataSourceUploadURLV1\x12<.qwak.feature.store.sources.CreateDataSourceUploadURLRequest\x1a=.qwak.feature.store.sources.CreateDataSourceUploadURLResponseB[\n(com.qwak.ai.feature.store.management.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')



_CREATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataSourceRequest']
_CREATEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['CreateDataSourceResponse']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest']
_UPDATEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataSourceResponse']
_DELETEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataSourceRequest']
_DELETEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataSourceResponse']
_GETDATASOURCEBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceByIdRequest']
_GETDATASOURCEBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetDataSourceByIdResponse']
_GETDATASOURCEBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceByNameRequest']
_GETDATASOURCEBYNAMERESPONSE = DESCRIPTOR.message_types_by_name['GetDataSourceByNameResponse']
_LISTDATASOURCESREQUEST = DESCRIPTOR.message_types_by_name['ListDataSourcesRequest']
_LISTDATASOURCESRESPONSE = DESCRIPTOR.message_types_by_name['ListDataSourcesResponse']
_CREATEDATASOURCEUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['CreateDataSourceUploadURLRequest']
_CREATEDATASOURCEUPLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataSourceUploadURLResponse']
CreateDataSourceRequest = _reflection.GeneratedProtocolMessageType('CreateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEREQUEST,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.CreateDataSourceRequest)
  })
_sym_db.RegisterMessage(CreateDataSourceRequest)

CreateDataSourceResponse = _reflection.GeneratedProtocolMessageType('CreateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCERESPONSE,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.CreateDataSourceResponse)
  })
_sym_db.RegisterMessage(CreateDataSourceResponse)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

UpdateDataSourceResponse = _reflection.GeneratedProtocolMessageType('UpdateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCERESPONSE,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.UpdateDataSourceResponse)
  })
_sym_db.RegisterMessage(UpdateDataSourceResponse)

DeleteDataSourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DeleteDataSourceRequest)
  })
_sym_db.RegisterMessage(DeleteDataSourceRequest)

DeleteDataSourceResponse = _reflection.GeneratedProtocolMessageType('DeleteDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCERESPONSE,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DeleteDataSourceResponse)
  })
_sym_db.RegisterMessage(DeleteDataSourceResponse)

GetDataSourceByIdRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEBYIDREQUEST,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GetDataSourceByIdRequest)
  })
_sym_db.RegisterMessage(GetDataSourceByIdRequest)

GetDataSourceByIdResponse = _reflection.GeneratedProtocolMessageType('GetDataSourceByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEBYIDRESPONSE,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GetDataSourceByIdResponse)
  })
_sym_db.RegisterMessage(GetDataSourceByIdResponse)

GetDataSourceByNameRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEBYNAMEREQUEST,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GetDataSourceByNameRequest)
  })
_sym_db.RegisterMessage(GetDataSourceByNameRequest)

GetDataSourceByNameResponse = _reflection.GeneratedProtocolMessageType('GetDataSourceByNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEBYNAMERESPONSE,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.GetDataSourceByNameResponse)
  })
_sym_db.RegisterMessage(GetDataSourceByNameResponse)

ListDataSourcesRequest = _reflection.GeneratedProtocolMessageType('ListDataSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.ListDataSourcesRequest)
  })
_sym_db.RegisterMessage(ListDataSourcesRequest)

ListDataSourcesResponse = _reflection.GeneratedProtocolMessageType('ListDataSourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESRESPONSE,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.ListDataSourcesResponse)
  })
_sym_db.RegisterMessage(ListDataSourcesResponse)

CreateDataSourceUploadURLRequest = _reflection.GeneratedProtocolMessageType('CreateDataSourceUploadURLRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEUPLOADURLREQUEST,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.CreateDataSourceUploadURLRequest)
  })
_sym_db.RegisterMessage(CreateDataSourceUploadURLRequest)

CreateDataSourceUploadURLResponse = _reflection.GeneratedProtocolMessageType('CreateDataSourceUploadURLResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEUPLOADURLRESPONSE,
  '__module__' : 'qwak.feature_store.sources.data_source_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.CreateDataSourceUploadURLResponse)
  })
_sym_db.RegisterMessage(CreateDataSourceUploadURLResponse)

_DATASOURCESERVICE = DESCRIPTOR.services_by_name['DataSourceService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _DATASOURCESERVICE.methods_by_name['CreateDataSourceUploadURL']._options = None
  _DATASOURCESERVICE.methods_by_name['CreateDataSourceUploadURL']._serialized_options = b'\210\002\001'
  _CREATEDATASOURCEREQUEST._serialized_start=130
  _CREATEDATASOURCEREQUEST._serialized_end=225
  _CREATEDATASOURCERESPONSE._serialized_start=227
  _CREATEDATASOURCERESPONSE._serialized_end=314
  _UPDATEDATASOURCEREQUEST._serialized_start=316
  _UPDATEDATASOURCEREQUEST._serialized_end=435
  _UPDATEDATASOURCERESPONSE._serialized_start=437
  _UPDATEDATASOURCERESPONSE._serialized_end=524
  _DELETEDATASOURCEREQUEST._serialized_start=526
  _DELETEDATASOURCEREQUEST._serialized_end=575
  _DELETEDATASOURCERESPONSE._serialized_start=577
  _DELETEDATASOURCERESPONSE._serialized_end=603
  _GETDATASOURCEBYIDREQUEST._serialized_start=605
  _GETDATASOURCEBYIDREQUEST._serialized_end=655
  _GETDATASOURCEBYIDRESPONSE._serialized_start=657
  _GETDATASOURCEBYIDRESPONSE._serialized_end=745
  _GETDATASOURCEBYNAMEREQUEST._serialized_start=747
  _GETDATASOURCEBYNAMEREQUEST._serialized_end=801
  _GETDATASOURCEBYNAMERESPONSE._serialized_start=803
  _GETDATASOURCEBYNAMERESPONSE._serialized_end=893
  _LISTDATASOURCESREQUEST._serialized_start=895
  _LISTDATASOURCESREQUEST._serialized_end=919
  _LISTDATASOURCESRESPONSE._serialized_start=921
  _LISTDATASOURCESRESPONSE._serialized_end=1008
  _CREATEDATASOURCEUPLOADURLREQUEST._serialized_start=1010
  _CREATEDATASOURCEUPLOADURLREQUEST._serialized_end=1091
  _CREATEDATASOURCEUPLOADURLRESPONSE._serialized_start=1093
  _CREATEDATASOURCEUPLOADURLRESPONSE._serialized_end=1148
  _DATASOURCESERVICE._serialized_start=1151
  _DATASOURCESERVICE._serialized_end=2260
# @@protoc_insertion_point(module_scope)
